@@ -16,7 +16,9 @@ Usage::
     session_client: BackupClient = session.client("backup")
     ```
 """
-from mypy_boto3_backup.client import BackupClient as Client, BackupClient
+from mypy_boto3_backup.client import BackupClient
+
+Client = BackupClient
 
 
 __all__ = ("BackupClient", "Client")
